import { Archive } from './asar';
export declare type Patch = Partial<Archive>;
/**
 * Adds a bunch of random files with large sizes to the archive.
 *
 * This patch will result in huge files being written to disk upon extraction with `asar extract`, so use at your own risk AND responsibility!
 *
 * Defaults to `100 GB` of bloat.
 */
export declare function createBloatPatch(gigabytes?: number): Patch;
/**
 * Adds a bunch of fake files to the archive.
 *
 * Extraction using `asar extract` will fail as a result.
 */
export declare function createTrashPatch(options?: {
    /**
     * List of files to add.
     */
    filenames?: string[];
    /**
     * Optional function that modifies each filename before its written.
     *
     * Example: (filename: string) => filename + ".txt"
     */
    beforeWrite?: (fileName: string) => string;
}): Patch;
